@@ -156,6 +156,8 @@ function loadTable(href) {
     table = $('#csv-data').DataTable({
         "responsive": true,
         "aaData": data,
+        /* Disable initial sort */
+        "aaSorting": [],
         "columns": headers,
         "initComplete": function (settings, json) {  
             $("#csv-data").wrap("<div style='overflow:auto; width:100%;position:relative;'></div>");
@@ -176,6 +178,10 @@ function loadOther(file) {
         Prism.highlightAll() });
 }
 
+function loadImage(URL) {
+    $("#file-content").html(`<img src='${URL}' style='max-width:100%'>`)
+}
+
 function loadDescription(description) {
     $("#file-content").html(`<pre style="white-space:pre-wrap;" id="pre-code"><code id="codeBlock" class="language-text animated fadeIn"></code>`)
     
@@ -429,6 +435,10 @@ var contentFunctions = {
         "load" : [loadStructure, "href"],
         "resize": "structure",
     },
+    "png": {
+        "load": [loadImage, "href"],
+        "resize": "file-content",
+    },
     "other": {
         "load": [loadOther, "href"],
         "resize": "file-content",
@@ -443,6 +453,7 @@ $(document).ready(function() {
     url = loc_string.split('?')
     const jobID = url[0];
     const initial_filename = url[1];
+    let current, new_url;
 
     // Get info we need for page
     let jobData = getJobData(jobID);
@@ -523,6 +534,30 @@ $(document).ready(function() {
         }
     )
 
+    // Hide the back button if previous doesn't exist
+    // or if it doesn't redirect to current site
+    if (previous == null) {
+        document.getElementById("back").classList.add("hidden")
+    }
+    else {
+        current = new URL(location.href)
+        new_url = new URL(previous)
+
+        if (current.hostname != new_url.hostname) {
+            document.getElementById("back").classList.add("hidden")
+        }
+    }
+
+    // Make the back button work
+    $("#back").click(
+        function() {
+            // Make sure origin is the same
+            if (current.origin == new_url.origin) {
+                window.location = previous;
+                location.reload();
+            }
+        }
+    )
 
     toggleDivs(contentDivs, "file-content")
     
